### Coarse Grained Coordinates of Atomistic Polystyrene ###
### JS 02/19/2017 ###

# defines draw parameters
draw delete all
draw materials on
draw material Transparent

# defines frame range
set mol [molinfo top] 
set nf [molinfo $mol get numframes]
set fin_frame $nf 
set ini_frame [expr $nf - 1] 

# polymer counting statistics definition
set log [open com_AA_unwrapped.txt w] 
set natom_per_chain FILL
# when debugging, set nchains = 1 
set nchains 1
set natom_per_monomer 16
set nbeads 10

# bead A counting statistics and draw definition
set firstbead_A FILL
set secondbead_A FILL

# Loop over A beads
for {set i $ini_frame} {$i < $fin_frame} {incr i} { #repeat the loop over frames
	for {set j 1} {$j <= $nchains} {incr j} { #repeats the loop over individual chains  
	
		# For the first atom, which counts differently due to the extra hydrogen. The below lines define coordinates of the bead and logs it
		set firstatom [atomselect top "index [expr ($j-1)*$natom_per_chain+$firstbead_A]"]
		$firstatom frame $i
		set com1 [measure center $firstatom]
		puts $log "$com1"
		# This line outputs the index you chose - good for debugging
		puts "Atom A # [expr ($j-1)*$natom_per_chain+$firstbead_A]" 
		# draws sphere on the index to validate
					  		
		# For rest of the atoms, use this loop
		for {set k 1} {$k <= [expr $nbeads-1]} {incr k} { 
   			set firstatom [atomselect top "index [expr ($j-1)*$natom_per_chain+$natom_per_monomer*($k-1)+$secondbead_A]"]
			$firstatom frame $i
			set com1 [measure center $firstatom]
			puts $log "$com1"	
		puts "Atom A # [expr ($j-1)*$natom_per_chain+$natom_per_monomer*($k-1)+$secondbead_A]"
		
	    }
    } 
}
flush $log
    	
		
# Repeat procedure for bead B
set log [open com_BB_unwrapped.txt w] 
# need to define two opposite coordinates of the phenyl ring to get COM
set firstbead_B1 FILL
set secondbead_B1 FILL
set firstbead_B2 FILL
set secondbead_B2 FILL
# Loop over B beads
for {set i $ini_frame} {$i < $fin_frame} {incr i} { #repeat the loop over frames 
	for {set j 1} {$j <= $nchains} {incr j} { #repeats the loop over individual chains
	
        # For the first atom in chain
		set secondatom [atomselect top "index [expr ($j-1)*$natom_per_chain+$firstbead_B1] [expr ($j-1)*$natom_per_chain+$firstbead_B2]"]
		$secondatom frame $i
		set com2 [measure center $secondatom]
		puts $log "$com2"
		# this line outputs the two indices you chose for defining the COM of bead B
		puts "Atom B # [expr ($j-1)*$natom_per_chain+$firstbead_B1] [expr ($j-1)*$natom_per_chain+$firstbead_B2]" 
		
		# For rest of the atoms in chain
   		for {set k 1} {$k <= [expr $nbeads-1]} {incr k} { 
		set secondatom [atomselect top "index [expr ($j-1)*$natom_per_chain+$natom_per_monomer*($k-1)+$secondbead_B1] [expr ($j-1)*$natom_per_chain+$natom_per_monomer*($k-1)+$secondbead_B2]"]
		$secondatom frame $i
		set com2 [measure center $secondatom]
		puts $log "$com2"
		puts "Atom B # [expr ($j-1)*$natom_per_chain+$natom_per_monomer*($k-1)+$secondbead_B1] [expr ($j-1)*$natom_per_chain+$natom_per_monomer*($k-1)+$secondbead_B2]"
			
	    }
    } 
}
flush $log
