clear
raw_dataA=importdata('com_AA_unwrapped.txt');
raw_dataB=importdata('com_BB_unwrapped.txt');
monomers_chain=10;
chains=50;
beadsA=monomers_chain*chains;
beadsB=monomers_chain*chains;
atoms=beadsA+beadsB;
massA=27.046;
massB=77.106;
bonds_chain=(2*monomers_chain-1);
atoms=chains*monomers_chain*2;
bonds=bonds_chain*chains;
atomtypes=2;
bondtypes=2;
frames=size(raw_dataA,1)/beadsA;

%set periodic box dimensions
lx=2*21.5057;
xlo=-lx/2;
xhi=lx/2;
ylo=-lx/2;
yhi=lx/2;
zlo=-lx/2;
zhi=lx/2;

% Create Molecule-tag
molecule=[];
for i=1:chains
    for j=1:monomers_chain*2
    molecule(j+(i-1)*monomers_chain*2)=i;
    end
end

% Charge
charge=[];
for i=1:atoms
    charge(i)=0;
end

% Define initial coordinates of atoms
coords=zeros(atoms,3);
for n=1:atoms/2
    coords(2*n-1,:)=raw_dataA(n,:);
    coords(2*n,:)=raw_dataB(n,:);
end

% Append Atom # and Atom type to coord
num=[1:atoms];
type=ones(1,atoms);
type(2:2:atoms)=2;
coord=[num',molecule',type',charge',coords];
coord=coord';

% bonds matrix
bond=zeros(bonds,3);
bond(:,1)=1:bonds;  %bond ID, first column

for k=1:chains
bond(((k-1)*bonds_chain+2):2:(k*bonds_chain-1),2)=2; %bond type 2, second column, A-A
bond(((k-1)*bonds_chain+1):2:k*bonds_chain,2)=1; %bond type 1, A-B

bond(((k-1)*bonds_chain+1):2:k*bonds_chain,3)=((k-1)*monomers_chain*2+1):2:(k*monomers_chain*2-1); % bond type 1; third column, odd row for each chain
bond(((k-1)*bonds_chain+1):2:k*bonds_chain,4)=((k-1)*monomers_chain*2+2):2:k*monomers_chain*2; % bond type 1; forth column, odd row for each chain

bond(((k-1)*bonds_chain+2):2:(k*bonds_chain-1),3)=((k-1)*monomers_chain*2+1):2:(k*monomers_chain*2-3); % bond type 2; third column, even row for each chain
bond(((k-1)*bonds_chain+2):2:(k*bonds_chain-1),4)=((k-1)*monomers_chain*2+3):2:(k*monomers_chain*2-1); % bond type 2; third column, even row for each chain
end

bond=bond';

%%% Create LAMMPS data file
filename = ['PSAA_RDF.data'];
fid = fopen(filename, 'w');

% Title
fprintf(fid, 'LAMMPS data file for Coarse Grained Polystyrene\n\n');

% num of atoms, bonds, etc...
fprintf(fid, '%1.0f atoms\n', atoms);
fprintf(fid, '%1.0f bonds\n', bonds);

fprintf(fid, '%1.0f atom types\n', atomtypes);
fprintf(fid, '%1.0f bond types\n\n', bondtypes);

% simulation box size for periodic systems
fprintf(fid, '%1.6f %1.6f xlo xhi\n', xlo, xhi);
fprintf(fid, '%1.6f %1.6f ylo yhi\n', ylo, yhi);
fprintf(fid, '%1.6f %1.6f zlo zhi\n\n', zlo, zhi);

% Masses
fprintf(fid, 'Masses\n\n');
fprintf(fid, '%1.0f %1.6f\n', 1, massA);
fprintf(fid, '%1.0f %1.6f\n\n', 2, massB);

% Atoms
fprintf(fid, 'Atoms\n\n');
fprintf(fid, '%4.0f %6.0f %6.0f %6.2f %12.6f %12.6f %12.6f\n',coord);

% Bonds
fprintf(fid, '\n');
fprintf(fid, 'Bonds\n\n');
fprintf(fid, '%4.0f %6.0f %6.0f %6.0f\n',bond);

fclose(fid);
